.. _guides:

===============
 How-to Guides
===============

How-to guides are step-by-step instructions on how to do specific tasks.

For a deeper and elaborate exploration of other SymPy topics, see the
:ref:`Explanations <explanations>` and  :ref:`API reference
<reference>` sections.

.. toctree::
   :maxdepth: 1

   assumptions.rst
   booleans.rst
   custom-functions.md
   solving/index.md
   ../citing.md
